@@ -21,9 +21,9 @@ int __mingw_asprintf(char ** __restrict__ ret,
     goto _end;
   }
   /* Write String */
-  __mingw_vsnprintf(*ret,len,format,ap);
+  __mingw_vsnprintf(*ret,len+1,format,ap);
   /* Terminate explicitly */
-  *ret[len] = '\0';
+  (*ret)[len] = '\0';
   _end:
   va_end(ap);
   return len;
